@@ -84,19 +84,20 @@ geom_heat_grid <- function(outside,
 
   if(r <= 2){rlang::abort(message = "`r` has to be greater than 2.")}
 
-  if(is.null(outside_name)) {outside_name = rlang::expr({{ outside }})}
-
-  if(is.null(inside_name)) {inside_name = rlang::expr({{ inside }})}
+  # if(is.null(outside_name)) {outside_name = rlang::expr({{ outside }})}
+  # if(is.null(inside_name)) {inside_name = rlang::expr({{ inside }})}
+  if (is.null(outside_name)) outside_name <- rlang::as_label(rlang::enexpr(outside))
+  if (is.null(inside_name))  inside_name  <- rlang::as_label(rlang::enexpr(inside))
 
   list(geom_tile_outside(ggplot2::aes(fill = {{ outside }})),
 
-       ggplot2::scale_fill_gradientn(outside_name, colors = outside_colors, ...),
+       ggplot2::scale_fill_gradientn(name = outside_name, colors = outside_colors, ...),
 
        ggnewscale::new_scale_fill(),
 
        geom_tile_inside(ggplot2::aes(fill = {{ inside }}, r = r)),
 
-       ggplot2::scale_fill_gradientn(inside_name, colors = inside_colors, ...))
+       ggplot2::scale_fill_gradientn(name = inside_name, colors = inside_colors, ...))
 
 }
 
